@@ -15,7 +15,7 @@ impl HashedPassword for BaseHashedPassword {
 }
 
 impl BaseHashedPassword { 
-    pub fn new() -> Self { 
-        BaseHashedPassword{}
+    pub fn new() -> Result<Self, std::io::Error> { 
+        Ok(BaseHashedPassword{})
     }
 }
