@@ -6,6 +6,7 @@ use crate::{token::Token, hashed_password::HashedPassword, public_key::PublicKey
 pub trait User { 
     fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<Token, std::io::Error>;
     fn hashed_password(&self) -> Arc<dyn HashedPassword + Send + Sync>;
+    fn public_key(&self) -> &PublicKey;
 }
 
 pub struct BaseUser { 
@@ -21,6 +22,10 @@ impl User for BaseUser {
     fn hashed_password(&self) -> Arc<dyn HashedPassword + Send + Sync> { 
         self._hashed_password.clone()
     }
+
+    fn public_key(&self) -> &PublicKey { 
+        &self._public_key
+    }
 }
 
 impl BaseUser { 
